﻿using Microsoft.Extensions.Caching.Memory;
using System;

namespace DependencyInjectionFromStartupBackToProgram
{
    public class TokenGenerator : ITokenGenerator
    {
        private readonly IMemoryCache _memoryCache;
        public TokenGenerator(IMemoryCache memoryCache)
        {
            _memoryCache = memoryCache;
        }

        public string GetToken()
        {
            string token;
            if (_memoryCache.TryGetValue("Token", out token))
            {
                return token;
            }
            else
            {
                // here you would have a more realistic way of generating a new token
                token = Guid.NewGuid().ToString();
                _memoryCache.Set("Token", token, TimeSpan.FromSeconds(10));

                return token;
            }
        }
    }
}


 